[evince] ev-file-helpers: use same parameter name between header and function



commit d37cbf313563f671aef878ab457235dc0b77d60b
Author: Cosimo Cecchi <cosimoc gnome org>
Date:   Mon Jan 7 00:13:08 2013 +0100

    ev-file-helpers: use same parameter name between header and function
    
    https://bugzilla.gnome.org/show_bug.cgi?id=691354

 libdocument/ev-file-helpers.c |   18 +++++++++---------
 libdocument/ev-file-helpers.h |    6 +++---
 2 files changed, 12 insertions(+), 12 deletions(-)
---
diff --git a/libdocument/ev-file-helpers.h b/libdocument/ev-file-helpers.h
index ba0d1f9..45d1453 100644
--- a/libdocument/ev-file-helpers.h
+++ b/libdocument/ev-file-helpers.h
@@ -40,12 +40,12 @@ void        _ev_file_helpers_init     (void);
 
 void        _ev_file_helpers_shutdown (void);
 
-int          ev_mkstemp               (const char        *the_template,
+int          ev_mkstemp               (const char        *tmpl,
                                        char             **file_name,
                                        GError           **error);
-GFile       *ev_mkstemp_file          (const char        *the_template,
+GFile       *ev_mkstemp_file          (const char        *tmpl,
                                        GError           **error);
-gchar       *ev_mkdtemp               (const char        *the_template,
+gchar       *ev_mkdtemp               (const char        *tmpl,
                                        GError           **error);
 void         ev_tmp_filename_unlink   (const gchar       *filename);
 void         ev_tmp_file_unlink       (GFile             *file);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/libdocument/ev-file-helpers.c b/libdocument/ev-file-helpers.c
index 1ab18a6..a1311bf 100644
--- a/libdocument/ev-file-helpers.c
+++ b/libdocument/ev-file-helpers.c
@@ -115,7 +115,7 @@ _ev_file_helpers_shutdown (void)
 
 /**
  * ev_mkstemp:
  * @template: a template string; must contain 'XXXXXX', but not necessarily as a suffix
  * @file_name: a location to store the filename of the temp file
  * @error: a location to store a #GError
  *
@@ -125,7 +125,7 @@ _ev_file_helpers_shutdown (void)
  *   on error with @error filled in
  */
 int
-ev_mkstemp (const char  *template,
+ev_mkstemp (const char  *tmpl,
             char       **file_name,
             GError     **error)
 {
@@ -136,7 +136,7 @@ ev_mkstemp (const char  *template,
         if ((tmp = _ev_tmp_dir (error)) == NULL)
               return -1;
 
-        name = g_build_filename (tmp, template, NULL);
+        name = g_build_filename (tmp, tmpl, NULL);
         fd = g_mkstemp (name);
 
         if (fd == -1) {
@@ -166,7 +166,7 @@ close_fd_cb (gpointer fdptr)
 
 /**
  * ev_mkstemp_file:
  * @template: a template string; must contain 'XXXXXX', but not necessarily as a suffix
  * @error: a location to store a #GError
  *
  * Creates a temp #GFile in the evince temp directory. See ev_mkstemp() for more information.
@@ -175,14 +175,14 @@ close_fd_cb (gpointer fdptr)
  *   on error with @error filled in
  */
 GFile *
-ev_mkstemp_file (const char        *template,
+ev_mkstemp_file (const char        *tmpl,
                  GError           **error)
 {
         char *file_name;
         int fd;
         GFile *file;
 
-        fd = ev_mkstemp (template, &file_name, error);
+        fd = ev_mkstemp (tmpl, &file_name, error);
         if (fd == -1)
                 return NULL;
 
@@ -282,7 +282,7 @@ _ev_g_mkdtemp (gchar *tmpl)
 
 /**
  * ev_mkdtemp:
  * @template: a template string; must end in 'XXXXXX'
  * @error: a location to store a #GError
  *
  * Creates a temp directory in the evince temp directory.
@@ -291,7 +291,7 @@ _ev_g_mkdtemp (gchar *tmpl)
  *   on error with @error filled in
  */
 gchar *
-ev_mkdtemp (const char        *template,
+ev_mkdtemp (const char        *tmpl,
             GError           **error)
 {
         const char *tmp;
@@ -300,7 +300,7 @@ ev_mkdtemp (const char        *template,
         if ((tmp = _ev_tmp_dir (error)) == NULL)
               return NULL;
 
-        name = g_build_filename (tmp, template, NULL);
+        name = g_build_filename (tmp, tmpl, NULL);
         if (_ev_g_mkdtemp (name) == NULL) {
 		int errsv = errno;
 
@@ -115,7 +115,7 @@ _ev_file_helpers_shutdown (void)
 /**
  * ev_mkstemp:
- * @template: a template string; must contain 'XXXXXX', but not necessarily as a suffix
+ * @tmpl: a template string; must contain 'XXXXXX', but not necessarily as a suffix
  * @file_name: a location to store the filename of the temp file
  * @error: a location to store a #GError
@@ -166,7 +166,7 @@ close_fd_cb (gpointer fdptr)
 /**
  * ev_mkstemp_file:
- * @template: a template string; must contain 'XXXXXX', but not necessarily as a suffix
+ * @tmpl: a template string; must contain 'XXXXXX', but not necessarily as a suffix
  * @error: a location to store a #GError
  *
@@ -282,7 +282,7 @@ _ev_g_mkdtemp (gchar *tmpl)
 /**
  * ev_mkdtemp:
- * @template: a template string; must end in 'XXXXXX'
+ * @tmpl: a template string; must end in 'XXXXXX'
  * @error: a location to store a #GError
  *